insightAdmin(1)

insightAdmin - Online Documentation Administration Utility

As shipped in IRIX 6.5.22. Last changed in IRIX 6.5.19.

NAME
     insightAdmin - Online Documentation Administration Utility

SYNOPSIS
     insightAdmin [ -v ] [ -h ] [ -c ] [ -d ] bookshelf_path


DESCRIPTION
     The insightAdmin utility is used to maintain the library of online books
     available to the infosearch(1) and sgihelp(1) viewing technologies.

     This utility program will update the list of books available on any
     particular (specified) bookshelf. This list is created/stored in the file
     <bookshelf_path>/booklist.txt. It also constructs library and bookshelf-
     level HTML files which can be browsed using any WWW (web) browser or
     through the IRIX Interactive Desktop.

     After the installation or removal of book(s) via the inst(1M) command,
     inst automatically runs the insightAdmin command on the necessary
     bookshelf.

     An administrator will need to run insightAdmin:

     o    When books have been removed via the rm(1) command, or by some means
          other than using inst(1M) (the standard process).

     o    To convert any books that may be in the old (unreadable) Insight
          format. See the discussion of the -c option below.

     o    If they feel as though the online documentation library is out-of-
          sync (for some reason).

     In any of the cases listed above, the administrator should then run
     insightAdmin on the necessary bookshelf(s) using the appropriate
     command-line options.

DEFINITIONS
     A bookshelf is defined as a directory containing a set of books. By
     default, bookshelves are located in:

       /usr/share/Insight/library/SGI_bookshelves

     To examine a sample bookshelf, look under this default path. Most of the
     directories contained under this area are defined as bookshelves. By
     convention, below each of those bookshelf directories exists a
     subdirectory named "books". The "books" subdirectory contains all
     available online books for this bookshelf.

     For example, examining the path:

       /usr/share/Insight/library/SGI_bookshelves/SGI_EndUser/books/Desktop_UG

     SGI_EndUser is the bookshelf and Desktop_UG is the book.


OPTIONS
     Command line options are described below.

     -a   The -a option is no longer needed and is ignored.

     -c   The -c option instructs insightAdmin to convert any books on the
          specified bookshelf that cannot be read (old format books). By
          default, this conversion is accomplished by sending the book through
          a local filtering process.

          Optionally, downloading the "packaged" book(s) from the Silicon
          Graphics Technical Publications Library website
          (http://techpubs.sgi.com) can be initiated if the -d option is
          specified. If (for some reason) the download fails, then the local
          filtering process is attempted upon the book(s) that encountered
          problems.

          Note that this conversion stage may take some time and should be
          used with caution. The amount of time varies with the number and
          size of the book(s) that need to be converted (could be from 1 to 3
          minutes or more per book).

          If you wish to first determine which books need to be converted
          and/or which bookshelves to run the insightAdmin command on, you can
          first run insightAdmin in verbose mode (using the default online
          documentation library path, which will check all bookshelves):

            insightAdmin -v

     -d   The -d option instructs insightAdmin to attempt to download
          "packaged" book(s) as part of a conversion operation (see -c). Books
          are downloaded from the Silicon Graphics Technical Publications
          Library website (http://techpubs.sgi.com).

          The geturl(1) command is used in conjunction with this operation.
          Note that if you utilize a proxy server, the communication library
          geturl(1) employs may need to be configured properly.  This can be
          done through the webcontrol panel.  See webcontrol(1) for details.

     -f   The -f option instructs insightAdmin to force the addition or
          replacement of each book's title to the bookshelf's list of book
          titles (booklist.txt). The -f option is no longer needed and is
          ignored.

     -h   The -h option instructs insightAdmin to print its usage message.

     -l   The -l lib_path option is no longer needed and is ignored.

     -v   The -v option instructs insightAdmin to output additional
          information.  This includes warnings about "old/unreadable format"
          books. If this warning occurs, you should consider installing a new
          copy of the book (if available), or re-run insightAdmin with the
          conversion option(s): -c and (if so desired) -d. By default,
          insightAdmin runs silently.

     bookshelf_path
          The bookshelf_path option specifies the bookshelf on which to run
          the administration tool. If this option is not specified,
          insightAdmin will work on all bookshelves below the default online
          documentation library path:

          /usr/share/Insight/library/SGI_bookshelves/


FILES
     /usr/sbin/insightAdmin


EXAMPLES
     Update the SGI_EndUser bookshelf.

       insightAdmin -v /usr/share/Insight/library/SGI_bookshelves/SGI_EndUser

     Convert any old-format books found on the SGI_Admin bookshelf to the new
     format.

       insightAdmin -v -c /usr/share/Insight/library/SGI_bookshelves/SGI_Admin

     Activate the download option (from http://techpubs.sgi.com) when
     converting any old-format books found on the Help bookshelf to the new
     format.

       insightAdmin -v -c -d /usr/share/Insight/library/SGI_bookshelves/Help


NOTES
     To browse the available bookshelves and books on the local system, in
     your web browser or in the IRIX Interactive Desktop File Manager, open
     the following file:

       /usr/share/Insight/library/SGI_bookshelves/index.html

     Localized books can be browsed by opening the following file:

       /usr/share/Insight/library/<language>_bookshelves/index.html

     Specifically, here is one such file (available only if localized books
     have been installed):

       /usr/share/Insight/library/fr_bookshelves/index.html
     If you see warnings about books in an "old/unreadable format", those
     books can be converted using the -c and (optionally) the -d option(s).
     Additional information can be found in the insight Release Notes.


SEE ALSO
     infosearch(1), sgihelp(1), insight(1), geturl(1)

     insight Release Notes.